aboutsummaryrefslogtreecommitdiff
path: root/tar.c
diff options
context:
space:
mode:
authorEric Andersen <andersen@codepoet.org>2000-11-14 22:15:48 +0000
committerEric Andersen <andersen@codepoet.org>2000-11-14 22:15:48 +0000
commit3c5ee9a379dd837962041b63537e84c148143997 (patch)
treef51c6eddfc388f26e4e0dd8faffc7394e6151493 /tar.c
parent46f0beb16723acec0f03859ba813209e96396901 (diff)
downloadbusybox-3c5ee9a379dd837962041b63537e84c148143997.tar.gz
Grammer fix. Changed "longer then" to "longer than". Fix thanks to Jim
Gleason <jimg@lineo.com>.
Diffstat (limited to 'tar.c')
-rw-r--r--tar.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/tar.c b/tar.c
index 4fd864b25..07c0e7105 100644
--- a/tar.c
+++ b/tar.c
@@ -39,7 +39,7 @@
#include "busybox.h"
#define BB_DECLARE_EXTERN
#define bb_need_io_error
-#define bb_need_name_longer_then_foo
+#define bb_need_name_longer_than_foo
#include "messages.c"
#include <stdio.h>
#include <dirent.h>
@@ -535,7 +535,7 @@ static int readTarFile(const char* tarName, int extractFlag, int listFlag,
}
if ( skipNextHeaderFlag == TRUE ) {
skipNextHeaderFlag=FALSE;
- errorMsg(name_longer_then_foo, NAME_SIZE);
+ errorMsg(name_longer_than_foo, NAME_SIZE);
tarExtractRegularFile(&header, FALSE, FALSE);
continue;
}
@@ -915,7 +915,7 @@ static int writeFileToTarball(const char *fileName, struct stat *statbuf, void*
}
if (strlen(fileName) >= NAME_SIZE) {
- errorMsg(name_longer_then_foo, NAME_SIZE);
+ errorMsg(name_longer_than_foo, NAME_SIZE);
return ( TRUE);
}
@@ -1004,7 +1004,7 @@ static int writeTarFile(const char* tarName, int verboseFlag, char **argv,
}
/* To be pedantically correct, we would check if the tarball
* is smaller then 20 tar blocks, and pad it if it was smaller,
* but that isn't necessary for GNU tar interoperability, and
* so is considered a waste of space */
@@ -1004,7 +1004,7 @@ static int writeTarFile(const char* tarName, int verboseFlag, char **argv,
}
/* To be pedantically correct, we would check if the tarball
- * is smaller then 20 tar blocks, and pad it if it was smaller,
+ * is smaller than 20 tar blocks, and pad it if it was smaller,
* but that isn't necessary for GNU tar interoperability, and
* so is considered a waste of space */